import os
import gtk

from .common import get_icon_path

def StatusIcon(title):
    # TODO we can probably do this with get_icon_pixbuf()
    return gtk.status_icon_new_from_file(get_icon_path())

class PopupMenu(gtk.Menu):
    def __init__(self):
        gtk.Menu.__init__(self)

        self.quit_menuitem = gtk.MenuItem("_Quit")
        self.quit_menuitem.show_all()
        self.append(self.quit_menuitem)

    def onquit(self, handler):
        self.quit_menuitem.connect("activate", handler)

